Learn R Programming

admmDensestSubmatrix (version 0.1.0)

densub: densub

Description

Iteratively solves the convex optimization problem using ADMM.

Usage

densub(G, m, n, tau = 0.35, gamma = 6/(sqrt(m * n) * (q - p)),
  opt_tol = 1e-04, maxiter, quiet = TRUE)

Arguments

G

sampled binary matrix

m

number of rows in dense submatrix

n

number of columns in dense submatrix

tau

penalty parameter for equality constraint violation

gamma

\(l_1\) regularization parameter

opt_tol

stopping tolerance in algorithm

maxiter

maximum number of iterations of the algorithm to run

quiet

toggles between displaying intermediate statistics

Value

Rank one matrix with \(mn\) nonzero entries, matrix \(Y\) that is used to count the number of disagreements between \(G\) and \(X\)

Details

\(min |X|_* + gamma* |Y|_1 + 1_Omega_W (W) + 1_Omega_Q (Q) + 1_Omega_Z (Z)\)

s.t \(X - Y = 0\), \(X = W\), \(X = Z\),

where \(Omega_W (W)\), \(Omega_Q (Q)\), \(Omega_Z (Z)\) are the sets: \(Omega_W = {W in R^MxN | e^TWe = mn}\)

\(Omega_Q = {Q in R^MxN | Projection of Q on not N = 0}\)

\(Omega_Z = {Z in R^MxN | Z_ij <= 1 for all (i,j) in M x N}\)

\(Omega_Q = {Q in R^MxN | Projection of Q on not N = 0}\)

\(Omega_Z = {Z in R^MxN | Z_ij <= 1 for all (i,j) in M x N}\)

\(1_S\) is the indicator function of the set \(S\) in \(R^MxN\) such that \(1_S(X) = 0\) if \(X\) in \(S\) and +infinity otherwise