Learn R Programming

admmDensestSubmatrix (version 0.1.0)

plantedsubmatrix: Sample matrix

Description

Generates binary \((M,N)\) - matrix sampled from dense \((m,n)\) - submatrix.

Usage

plantedsubmatrix(M, N, m, n, p, q)

Arguments

M

number of rows in sampled matrix

N

number of rows in sampled matrix

m

number of rows in dense submatrix

n

natural number used to calculate number of rows in dense submatrix

p

density outside planted submatrix

q

density inside planted submatrix

Value

Matrix \(G\) sampled from the planted dense \((mn)\)-submatrix model, dense sumbatrix \(X0\), matrix \(Y0\) used to count the number of disagreements between \(G\) and \(X0\)

Details

Let \(U*\) and \(V*\) be \(m\) and \(n\) index sets. For each i in U*, j in V* we let \(a_ij = 1\) with probability \(q\) and \(0\) otherwise. For each remaining \(ij\) we set \(a_ij = 1\) with probability \(p < q\) and take \(a_ij = 0\) otherwise.

Examples

Run this code
# NOT RUN {
plantedsubmatrix(10,10,1,2,0.25,0.75)
# }

Run the code above in your browser using DataLab