natural number used to calculate number of rows in dense submatrix
p
density outside planted submatrix
q
density inside planted submatrix
Value
Matrix \(G\) sampled from the planted dense \((mn)\)-submatrix model, dense sumbatrix \(X0\), matrix \(Y0\) used to count the number of disagreements between \(G\) and \(X0\)
Details
Let \(U*\) and \(V*\) be \(m\) and \(n\) index sets.
For each i in U*, j in V* we let \(a_ij = 1\) with probability \(q\) and \(0\) otherwise.
For each remaining \(ij\) we set \(a_ij = 1\) with probability \(p < q\) and take \(a_ij = 0\) otherwise.